from distutils.core import setup

setup(
        name             = 'nester_first',
        version          = '1.0.1',
        py_modules       = ['nester_first'],
        author           = 'idyll',
        author_email     = 'idyllzhou@gmail.com',
        url              = 'www.sponia.com',
        description      = 'A simple printer of nested lists',
    )
